package com.ruoyi.project.asset.mapper;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.project.asset.domain.TSpecdevFixedAsset;

import java.util.List;

/**
 * 固定资产Mapper接口
 *
 * @author ruoyi
 * @date 2022-10-18
 */
public interface TSpecdevFixedAssetMapper
{
    /**
     * 查询固定资产
     *
     * @param id 固定资产ID
     * @return 固定资产
     */
    public TSpecdevFixedAsset selectTSpecdevFixedAssetById(Long id);

    /**
     * 查询固定资产列表
     *
     * @param tSpecdevFixedAsset 固定资产
     * @return 固定资产集合
     */
    @DataScope(deptAlias = "d")
    public List<TSpecdevFixedAsset> selectTSpecdevFixedAssetList(TSpecdevFixedAsset tSpecdevFixedAsset);

    /**
     * 新增固定资产
     *
     * @param tSpecdevFixedAsset 固定资产
     * @return 结果
     */
    public int insertTSpecdevFixedAsset(TSpecdevFixedAsset tSpecdevFixedAsset);

    /**
     * 修改固定资产
     *
     * @param tSpecdevFixedAsset 固定资产
     * @return 结果
     */
    public int updateTSpecdevFixedAsset(TSpecdevFixedAsset tSpecdevFixedAsset);

    /**
     * 删除固定资产
     *
     * @param id 固定资产ID
     * @return 结果
     */
    public int deleteTSpecdevFixedAssetById(Long id);

    /**
     * 批量删除固定资产
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTSpecdevFixedAssetByIds(Long[] ids);
}
